@@ -2,7 +2,7 @@ package InfluxDB::LineProtocol;
 use strict;
 use warnings;
 
-our $VERSION = '1.011';
+our $VERSION = '1.012';
 
 # ABSTRACT: Write and read InfluxDB LineProtocol
 
@@ -72,7 +72,7 @@ sub _format_value {
     elsif ( $v =~ /^[Tt](?:RUE|rue)?$/ ) {
         $v = 'TRUE';
     }
-    elsif ( $v =~ /^-?\d+(?:\.\d+)?(?:e-?\d+)?$/ ) {
+    elsif ( $v =~ /^-?\d+(?:\.\d+)?(?:e(?:-|\+)?\d+)?$/ ) {
         # pass it on, no mod
     }
     else {
@@ -337,7 +337,7 @@ InfluxDB::LineProtocol - Write and read InfluxDB LineProtocol
 
 =head1 VERSION
 
-version 1.011
+version 1.012
 
 =head1 SYNOPSIS
 
@@ -494,6 +494,11 @@ L<mvgrimes|https://github.com/mvgrimes> for fixing a bug when
 nanosecond timestamps cause some Perls to render the timestamp in
 scientific notation.
 
+=item *
+
+L<Adrian Popa|https://github.com/mad-ady> for fixing a bug when
+handling large scientific notation data.
+
 =back
 
 =head1 AUTHOR
